@@ -311,6 +311,7 @@ struct WrapperConfig {
     TCHAR   key[17];                /* Key which the JVM uses to authorize connections. (16 digits + \0) */
     int     isConsole;              /* TRUE if the wrapper was launched as a console. */
     int     cpuTimeout;             /* Number of seconds without CPU before the JVM will issue a warning and extend timeouts */
+    int     pidLogLevel;            /* The log level to use when logging the PID of the JVM after it is launched. */
     int     startupTimeout;         /* Number of seconds the wrapper will wait for a JVM to startup */
     int     pingTimeout;            /* Number of seconds the wrapper will wait for a JVM to reply to a ping */
     int     pingAlertThreshold;     /* Number of seconds without a ping response that the Wrapper will start to warn about a slow ping. */
@@ -393,6 +394,7 @@ struct WrapperConfig {
                                      *  This flag indicates that the action specified by wrapper.on_exit should be ignored. It must be reset after the JVM is
                                      *  restarted so that wrapper.on_exit can continue to catch JVM exit codes. */
     TCHAR*  shutdownActionPropertyName; /* Keep the name of the property that originated the shudown for logging. */
+    int     stopPacketReceived;     /* TRUE if a stop message was received, needed to be able to prevent sending other messages after that point. */ 
     int     stoppedPacketReceived;  /* TRUE if the STOPPED packet was received before a restart. */
     int     restartPacketReceived;  /* TRUE if the RESTART packet was received before a restart. */
     int     jvmRestarts;            /* Number of times that a JVM has been launched since the wrapper was started. */
@@ -468,6 +470,7 @@ struct WrapperConfig {
     DWORD   ntServicePriorityClass; /* Priority at which the Wrapper and its JVMS will run.
                                      * {HIGH_PRIORITY_CLASS | IDLE_PRIORITY_CLASS | NORMAL_PRIORITY_CLASS | REALTIME_PRIORITY_CLASS} */
     TCHAR   *ntServiceAccount;      /* Account name to use when running as a service.  NULL to use the LocalSystem account. */
+    int     ntServiceAddLogonAsService; /* Automatically add the 'Log on as a service' privilege to the service account. */
     TCHAR   *ntServicePassword;     /* Password to use when running as a service.  NULL means no password. */
     int     ntServicePrompt;        /* If true then the user will be prompted for a account name, domain,  password when installing as a service. */
     int     ntServicePasswordPrompt; /* If true then the user will be prompted for a password when installing as a service. */
@@ -1163,7 +1166,7 @@ extern int wrapperBuildJavaVersionCommand();
  *
  * @return The final index into the strings array, or -1 if there were any problems.
  */
-extern int wrapperBuildJavaCommandArrayJavaCommand(TCHAR **strings, int addQuotes, int detectDebugJVM, int index);
+extern int wrapperBuildJavaCommandArrayJavaCommand(TCHAR **strings, int addQuotes, int index);
 
 /**
  * Build the java command line.
