@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2019 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2020 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -163,6 +163,7 @@ int configFileReader_Read(ConfigFileReader *reader,
     int readResult = CONFIG_FILE_READER_SUCCESS;
     int ret;
     TCHAR *bufferW;
+    size_t bufferWSize;
 #ifdef WIN32
     int size;
 #endif
@@ -291,6 +292,18 @@ int configFileReader_Read(ConfigFileReader *reader,
     do {
         c = (TCHAR*)fgets(bufferMB, MAX_PROPERTY_NAME_VALUE_LENGTH, stream);
         if (c != NULL) {
+            /* First check if this line should be skipped (in some modes we know that passwords are not used, so we want to avoid store them in memory) */
+            if (reader->readFilterCallback && !reader->readFilterCallback(bufferMB)) {
+                /* Fill the buffer with 0 to ensure nothing remains in memory. */
+                wrapperSecureZero(bufferMB, sizeof(bufferMB));
+ #ifdef _DEBUG
+                printf("configFileReader_Read - address of bufferMB[0] (%c): %p\n", bufferMB[0], &(bufferMB[0]));
+                printf("configFileReader_Read - address of bufferMB[1] (%c): %p\n", bufferMB[1], &(bufferMB[1]));
+ #endif
+                lineNumber++;
+                continue;
+            }
+
 #ifdef WIN32
             ret = multiByteToWideChar(bufferMB, encoding, &bufferW, TRUE);
 #else
@@ -348,8 +361,11 @@ int configFileReader_Read(ConfigFileReader *reader,
                     continue;
                 }
                 fclose(stream);
+                wrapperSecureZero(bufferMB, sizeof(bufferMB));
                 return CONFIG_FILE_READER_HARD_FAIL;
             }
+            /* Store the size of the buffer because the callback will insert a 0 after any valid property name. */
+            bufferWSize = _tcslen(bufferW) * sizeof(TCHAR);
             
 #ifdef _DEBUG
             /* The line feeds are not yet stripped here. */
@@ -598,10 +614,13 @@ int configFileReader_Read(ConfigFileReader *reader,
             }
             
             /* Always free each line read. */
-            free(bufferW);
+            wrapperSecureFree(bufferW, bufferWSize);
         }
         lineNumber++;
     } while (c != NULL);
+    
+    /* Always fill the buffer with 0 when finished. */
+    wrapperSecureZero(bufferMB, sizeof(bufferMB));
 
     /* Call the callback after reading the file completely in order to copy reader->exitOnOverwrite & reader->logLevelOnOverwrite into the properties structure. 
      *  (we want to keep these values after preload for logging potential problems on properties defined in the command line)
@@ -627,6 +646,8 @@ int configFileReader_Read(ConfigFileReader *reader,
  *                     file will silently fail.
  * @param callback Pointer to a callback function which will be called for each line read.
  * @param callbackParam Pointer to additional user data which will be passed to the callback.
+ * @param readFilterCallback Pointer to a callback funtion which will be used to filter some
+ *                           lines that should not be processed.
  * @param enableIncludes If TRUE then includes will be supported.
  * @param preload TRUE if this is being called in the preload step meaning that all errors
  *                should be suppressed.
@@ -645,6 +666,7 @@ int configFileReader(const TCHAR *filename,
                      int fileRequired,
                      ConfigFileReader_Callback callback,
                      void *callbackParam,
+                     ConfigFileReader_ReadFilterCallbackMB readFilterCallback,
                      int enableIncludes,
                      int preload,
                      const TCHAR *originalWorkingDir,
@@ -657,6 +679,7 @@ int configFileReader(const TCHAR *filename,
     /* Initialize the reader. */
     reader.callback = callback;
     reader.callbackParam = callbackParam;
+    reader.readFilterCallback = readFilterCallback;
     reader.enableIncludes = enableIncludes;
     reader.preload = preload;
     reader.debugIncludes = FALSE;
