@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2019 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2020 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -465,6 +465,11 @@ extern int multiByteToWideChar(const char *multiByteChars, int encoding, TCHAR *
  #define FALSE 0
 #endif
 
+#define STATUS_UNCHANGED  0
+#define STATUS_ENABLED    1
+#define STATUS_DISABLED   2
+#define STATUS_UNKNOWN    3
+
 #ifndef WIN32
  #ifdef HPUX
   #define MB_UTF8   "utf8"
@@ -488,6 +493,14 @@ extern int multiByteToWideChar(const char *multiByteChars, int encoding, TCHAR *
 
 #define ENCODING_BUFFER_SIZE    32                                              /* ex: x-windows-iso2022jp */
 
+void wrapperSecureZero(void* str, size_t size);
+
+void wrapperSecureFree(void* str, size_t size);
+
+void wrapperSecureFreeStrW(TCHAR* str);
+
+void wrapperSecureFreeStrMB(char* str);
+
 extern TCHAR* toLower(const TCHAR* value);
 
 extern TCHAR* toUpper(const TCHAR* value);
